@@ -1,5 +1,6 @@
 import copy
 import json
+import logging
 import os
 import urllib.parse
 from collections import defaultdict
@@ -39,6 +40,10 @@ def build_intermediate_representation(
     # Make sure schema_path is absolute, all symlinks are resolved
     absolute_schema_path = _get_schema_path(schema_path)
 
+    loaded_schema = _load_schema(absolute_schema_path, [], loaded_schemas)
+    if not loaded_schema:
+        raise Exception("Cannot generate documentation since root schema could not be loaded")
+
     intermediate_representation = _build_node(
         config,
         resolved_references,
@@ -49,7 +54,7 @@ def build_intermediate_representation(
         "root",
         absolute_schema_path,
         [],
-        _load_schema(absolute_schema_path, [], loaded_schemas),
+        loaded_schema,
     )
 
     return intermediate_representation
@@ -284,16 +289,18 @@ def _get_schema_path(schema_path: Union[str, Path, FileLikeType]) -> str:
         return os.path.realpath(schema_path.name)
 
 
-def _get_node_ref(schema: Union[int, str, List, Dict]) -> str:
+def _get_node_ref(schema: Optional[Union[int, str, List, Dict]]) -> str:
     if isinstance(schema, dict) and const.REF in schema:
         return schema[const.REF]
     return ""
 
 
-def _load_schema_from_uri(schema_uri: str, loaded_schemas: Dict[str, Any]):
+def _load_schema_from_uri(schema_uri: str, loaded_schemas: Dict[str, Any]) -> Optional[Union[Dict, List, str, int]]:
     if schema_uri in loaded_schemas:
         loaded_schema = loaded_schemas[schema_uri]
-    else:
+        return loaded_schema
+
+    try:
         if schema_uri.startswith("http"):
             if schema_uri.endswith(".yaml"):
                 loaded_schema = yaml.safe_load(requests.get(schema_uri).text)
@@ -306,14 +313,17 @@ def _load_schema_from_uri(schema_uri: str, loaded_schemas: Dict[str, Any]):
                     loaded_schema = json.load(schema_fp)
                 else:
                     loaded_schema = yaml.safe_load(schema_fp)
-        loaded_schemas[schema_uri] = loaded_schema
+    except Exception as e:
+        logging.warning(f"Error loading schema from uri {schema_uri}: {e}")
+        return None
 
+    loaded_schemas[schema_uri] = loaded_schema
     return loaded_schema
 
 
 def _load_schema(
     schema_uri: str, path_to_element: List[Union[str, int]], loaded_schemas: Dict[str, Any]
-) -> Union[Dict, List, int, str]:
+) -> Optional[Union[Dict, List, int, str]]:
     """Load the schema at the provided path or URL.
 
     If the URI is for a local file, it must be a "realpath", meaning absolute and with symlinks resolved.
@@ -363,7 +373,7 @@ def _build_node(
     breadcrumb_name: str,
     schema_file_path: str,
     path_to_element: List[Union[str, int]],
-    schema: Union[Dict, List, int, str],
+    schema: Optional[Union[Dict, List, int, str]],
     parent: Optional[SchemaNode] = None,
     parent_key: Optional[str] = None,
 ) -> SchemaNode:
@@ -396,6 +406,25 @@ def _build_node(
     if not path_to_element:
         path_to_element = [ROOT_ID]
 
+    if schema is None:
+        # Happens only when a referenced schema could not be loaded
+        # For the root schema, we fail earlier
+        if depth == 0:
+            raise AssertionError(
+                "Tried to render a schema from a file that was not found. This is an error in the lib."
+            )
+        # Return a fake node that displays an error
+        new_node.keywords[const.DESCRIPTION] = SchemaNode(
+            depth=depth + 1,
+            file="",
+            path_to_element=path_to_element + ["error"],
+            html_id=html_id + "_error",
+            breadcrumb_name="error",
+            ref_path="",
+            literal="😅 ERROR in schema generation, a referenced schema could not be loaded, no documentation here unfortunately 🏜️",
+        )
+        return new_node
+
     _record_ref(resolved_references, schema_file_path, path_to_element, new_node)
 
     if isinstance(schema, dict):
